## 1. Tool validation and normalization

- [x] 1.1 Update shared tool validation to allow web_search/web_search_preview and normalize web_search_preview to web_search
- [x] 1.2 Apply tool validation to Responses requests (including /backend-api/codex/responses)
- [x] 1.3 Preserve web_search tools in chat tool normalization

## 2. Compatibility updates

- [x] 2.1 Update integration tests to expect web_search support and continued rejection of other built-ins
- [x] 2.2 Update live check expectations and compatibility plan support matrix
